@@ -3,7 +3,7 @@ import random
 
 from pysnmp.entity import engine, config
 from pysnmp.entity.rfc3413 import cmdrsp, context
-from pysnmp.carrier.asynsock.dgram import udp, udp6
+from pysnmp.carrier.asyncio.dgram import udp, udp6
 from pysnmp.proto.api import v2c
 
 
